@@ -1,8 +1,5 @@
 import abc
 
-from easytradesdk.entity.Symbol import Symbol
-from easytradesdk.entity.TC import TC
-
 
 class AbsContext(metaclass=abc.ABCMeta):
 
@@ -19,7 +16,7 @@ class AbsContext(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def getExecuteInterval(self):
+    def getExecutePeriod(self):
         pass
 
     @abc.abstractmethod
@@ -35,5 +32,5 @@ class AbsContext(metaclass=abc.ABCMeta):
         pass
 
     @abc.abstractmethod
-    def calculateMaxAvailableBuyQuantity(self, tc: TC, symbol: Symbol, amount=None, offsetPrice=None, scale=2):
+    def calculateMaxAvailableBuyQuantity(self, tc, symbol, amount=None, offsetPrice=None, scale=2):
         pass
