@@ -16,7 +16,13 @@ class DepthValue(DeserializableObject):
 
 class Depth(DeserializableObject):
 
-    def __init__(self, lastUpdateMills=0):
+    def __init__(self, bids=None, asks=None, lastUpdateMills=0):
+        if bids is None:
+            bids = []
+        if asks is None:
+            asks = []
+        self.bids = bids
+        self.asks = asks
         self.lastUpdateMills = lastUpdateMills
         self.bids = []
         self.asks = []
