@@ -19,11 +19,9 @@ class Cci(SimpleIndicator):
         for _t in range(0, len(time_periods)):
             _time_period = time_periods[_t]
             _cci_tmp_dict[_time_period] = ta.CCI(np_high_price_array, np_low_price_array, np_closing_price_array, timeperiod=_time_period)
-        _cci_array = []
+        _cci_list = []
         for _index in range(0, len(np_closing_price_array)):
-
             _cci = Cci()
-
             for t in range(0, len(time_periods)):
                 _time_period = time_periods[t]
                 _np_cci_Array = _cci_tmp_dict[_time_period]
@@ -33,6 +31,6 @@ class Cci(SimpleIndicator):
                     _cci.setValue(_cci_value, _time_period)
                 else:
                     _cci.setValue(None, _time_period)
-            _cci_array.append(_cci)
+            _cci_list.append(_cci)
 
-        return _cci_array
+        return _cci_list
