@@ -18,7 +18,7 @@ class Ema(SimpleIndicator):
             _time_period = time_periods[_t]
             _ema_dict[_time_period] = ta.EMA(np_closing_price_array, timeperiod=_time_period)
 
-        _ema_array = []
+        _ema_list = []
         for _index in range(0, len(np_closing_price_array)):
             _ema = Ema()
             for t in range(0, len(time_periods)):
@@ -30,6 +30,6 @@ class Ema(SimpleIndicator):
                     _ema.setValue(_v, _time_period)
                 else:
                     _ema.setValue(None, _time_period)
-            _ema_array.append(_ema)
+            _ema_list.append(_ema)
 
-        return _ema_array
+        return _ema_list
