@@ -18,7 +18,7 @@ class Wma(SimpleIndicator):
             _time_period = time_periods[_t]
             _wma_dict[_time_period] = ta.WMA(np_closing_price_array, timeperiod=_time_period)
 
-        _wma_array = []
+        _wma_list = []
         for _index in range(0, len(np_closing_price_array)):
             _wma = Wma()
             for t in range(0, len(time_periods)):
@@ -30,6 +30,6 @@ class Wma(SimpleIndicator):
                     _wma.setValue(_v, _time_period)
                 else:
                     _wma.setValue(None, _time_period)
-            _wma_array.append(_wma)
+            _wma_list.append(_wma)
 
-        return _wma_array
+        return _wma_list
